# punchbowl

`punchbowl` is the science calibration code for [the PUNCH mission](https://punch.space.swri.edu/).

> [!CAUTION]
> This package is still being developed. There will be breaking code changes until v1.
> We advise you to wait until then to use it.

## Accessing the data

Coming soon.

## Installing `punchbowl`

Coming soon.

## Running `punchbowl`

Coming soon.

## Getting help

Please open an issue or discussion on this repo.

## Contributing

We encourage all contributions.
If you have a problem with the code or would like to see a new feature, please open an issue.
Or you can submit a pull request.
